/**************************************************************************************************
	Developed by: the Colorado Health Institute (CHI)
	Contact Information: 
		Rebecca Crepin
		720.382.7086
		crepinr@coloradohealthinstitute.org

	The following is code used to assign formats to the variables in the 2011 Colorado
	Health Access Survey Public Use File. The code was written in SAS format but can be
	modified for use in other applications, such as SPSS or STATA.

	INPUT: CHAS2011_PUF.<ext>
	OUTPUT: A data file compatible with the user's computer system, with formats

***************************************************************************************************/

* provide name and pathname for data file;
%let datafile = /*<USER INPUT>*/ ;

proc format library=;
	value puf_gender
		-9 = "Dont know/refused"
		1 = "Male"
		2 = "Female"
	;
	value puf_age
		-9 = "Dont know/refused"
		1 = "0 to 18"
		2 = "19 to 34"
		3 = "35 to 54"
		4 = "55 to 64"
		5 = "65 and older"
	;
	value puf_educ
		-9 = "Dont know/refused"
		1 = "Less than high school"
		2 = "High school graduate or equivalent"
		3 = "Some college but no degree"
		4 = "Associates Degree"
		5 = "College graduate"
		6 = "Postgraduate"
	;
	value married
		0 = "NOT married/partner"
	  	1 = "TARGET is married/partner"
	;
	value puf_yn
		-9 = "Dont know/refused"
		1 = "Yes"
		2 = "No"
	;
	value puf_urban
		-9 = "Dont know/refused"
		1 = "Urban"
		2 = "Rural"
	;
	value noins_tm
		-9 = "Dont know/refused"
		1 = "0 to 11 months"
		2 = "12 months"
	;
	value tm_without
		-9 = "Dont know/refused"
		1 = "0 to 24 months"
		2 = "> 24 months"
	;
	value noins_reason
		-9 = "Dont know/refused"
		1 = "Cost is too high"
		2 = "Other"
	;
	value puf_hours
		-9 = "Dont know/refused"
		1 = "<40 hrs/week"
		2 = "40 hrs/week"
		3 = ">40 hrs/week"
	;
	value emp_tm
		-9 = "Dont know/refused"
		1 = "<1 year"
		2 = "1 to 5 years"
		3 = "6 to 10 years"
		4 = "11 to 20 years"
		5 = ">20 years"
	;
	value puf_sz
		-9 = "Dont know/refused"
		1 = "1 to 10 employees"
		2 = "11 to 50 employees"
		3 = "51 to 100 employees"
		4 = ">100 employees"
	;
	value puf_usoc
		-9 = "Dont know/refused"
		1 = "Doctor's office or private clinic"
		2 = "Community health center or other public clinic"
		3 = "Emergency room or urgent care center"
		4 = "Other type of place"
	;
	value num_people
		-9 = "Dont know/refused"
		1 = "1 person"
		2 = "2 people"
		3 = "3 people"
		4 = "4 people"
		5 = "5 or more people"
	;
	value live
		-9 = "Dont know/refused"
		1 = "0-10 years"
		2 = "11-20 years"
		3 = "20+ years"
	;
	value puf_oop
		-9 = "Dont know/refused"
		1 = "Zero (0)"
		2 = "$1 to <$200"
		3 = "$200 to <$500"
		4 = "$500 to <$1000"
		5 = "$1000 or more"
	;
	value puf_er
		-9 = "Dont know/refused"
		1 = "None"
		2 = "1 time"
		3 = "2 or more times"
	;
	value puf_health
		-9 = "Dont know/refused"
		1 = "Excellent/very good"
		2 = "Good"
		3 = "Fair/Poor"
	;
	value cell
		-9 = "Dont know/refused"
		1 = "1 person"
		2 = "2 people"
		3 = "3 or more"
	;
	value home
		-9 = "Dont know/refused"
		1 = "Own"
		2 = "Rent"
	;
	value puf_incyr
		-9 = "Dont know/refused"
		1 = "0 to $29,999"
		2 = "$30,000 to $59,999"
		3 = "$60,000 to $89,999"
		4 = "$90,000 and greater"
	;
	value puf_incmon
		-9 = "Dont know/refused"
		1 = "0 to $1,999"
		2 = "$2,000 to $3,999"
		3 = "$4,000 to $5,999"
		4 = "$6,000 and greater"
	;
	value puf_ins
		1 = "Employer"
		2 = "Medicare"
		3 = "Medicaid/CHP+"
		4 = "Private/Other"
		5 = "Uninsured"
	;
	value num_calls
		-9 = "Dont know/refused"
		1 = "Almost all calls"  
		2 = "More than half"  
		3 = "Less than half"  
		4 = "Very few or none"  
	;
	value puf_employ
		-9 = "Dont know/refused"
		1 = "Self-employed"
		2 = "Employed by someone else (inc military)"
		3 = "Retired"
		4 = "Unemployed and looking for work"
		5 = "Not employed/unpaid worker"
		6 = "Unable to work because of a disability"
	;
	value white
		-9 = "Dont know/refused"
		1 = "White"
		2 = "non-White"
	;
	value doc_visit
		-9 = "Dont know/refused"
		0 = "None"
		1 = "1 time"  
		2 = "2 times"  
		3 = "3 times"  
		4 = "More than 3 times"  
	;
	value had_choice
		-9 = "Dont know/refused"
		1 = "Yes"
	  	2 = "No"
	;
	value hc_choice
		-9 = "Dont know/refused"
		1 = "Definitely yes"
	  	2 = "Somewhat yes"
	 	3 = "Somewhat no"
	 	4 = "Definitely no"
	;
	value afford_mon_i
		0 = "0 (zero)"
		1 = "$1 to $25"
	  	2 = "$26 to $75"
	 	3 = "$76 to $150"
	 	4 = "$151 and greater"
	;
	value reform
		-9 = "Dont know/refused"
	  	1 = "Strongly agree"
	  	2 = "Somewhat agree"
	 	3 = "Somewhat disagree"
	  	4 = "Strongly disagree"
	;
	value reform
		-9 = "Dont know/refused"
	  	1 = "Strongly agree"
	  	2 = "Somewhat agree"
	 	3 = "Somewhat disagree"
	  	4 = "Strongly disagree"
	;
	value party
		-9 = "Dont know/refused"
	 	1 = "Democrat"
	 	2 = "Republican"
	  	3 = "Independent"
	  	4 = "Not registered to vote"
	;
	value provider
		-9 = "Dont know/refused"
	  	1 = "Provider took target''s insurance"
	  	2 = "Cost"
	  	3 = "Availability of appointments"
	  	4 = "The provider was located close to where you live or work"
	  	5 = "Recommendations from friends and family"
	  	6 = "Quality of the provider''s care"
	  	7 = "Gender of the health care provider"
	  	8 = "The provider spoke a language other than English"
	  	9 = "Not one reason"
	;
	value spanish
		1="Speak Spanish"
		0="Does not speak Spanish"
	;
	value spk_other
		1="Speak language other than Spanish"
		0="Does not speak a language other than Spanish"
	;
run;


proc datasets library = ;
	modify &datafile.;

	format AFFORD_MON_I afford_mon_i.;
	format AGE_GRP puf_age.;
	format CELL_CALLS num_calls.;
	format CELL_HH cell.;
	format COST_NODENT puf_yn.;
	format COST_NODOC puf_yn.;
	format COST_NORX puf_yn.;
	format COST_NOSPEC puf_yn.;
	format COST_NOMH puf_yn.;
	format CO_LIVED live.;
	format DENTAL_INS puf_yn.;
	format DENTIST_12M puf_yn.;
	format DOC_12M doc_visit.;
	format DOC_PREV puf_yn.;
	format EDUCATION puf_educ.;
	format EMPLOYED puf_yn.;
	format EMP_ADDJOB puf_yn.;
	format EMP_CATEGORY puf_employ.;
	format EMP_HRS_WK puf_hours.;
	format EMP_TIME emp_tm.;
	format ER_12M puf_er.;
	format ER_NOEMER puf_yn.;
	format ER_RES1 puf_yn.;
	format ER_RES2 puf_yn.;
	format ER_RES3 puf_yn.;
	format ESI_DEP puf_yn.;
	format ESI_OFFERED puf_yn.;
	format FIRM_ESI puf_yn.;
	format FIRM_SIZE puf_sz.;
	format GENDER puf_gender.;
	format hc_choice had_choice.;
 	format hc_choice_ask hc_choice.;
 	format hc_needs_co reform.;
 	format hc_needs_fam reform.;
	format HEALTH_STATUS puf_health.;
	format HOME_OWNER home.;
	format HOSP_12M puf_yn.;
	format INC_2010_GRP puf_incyr.;
	format INC_DIVIDEND puf_yn.;
	format INC_MON_GRP puf_incmon.;
	format INC_OTH puf_yn.;
	format INC_SALARY puf_yn.;
	format INSURANCE puf_ins.;
	format INSURED_12M puf_yn.;
	format INSURED_PIT puf_yn.;
	format LIMIT_ACTIVITY puf_yn.;
	format MARRIED married.;
	format NOCARE_APP puf_yn.;
	format NOCARE_INS puf_yn.;
	format NOCARE_NEWPT puf_yn.;
	format NOINS_12M puf_yn.;
	format NOINS_NUM noins_tm.;
	format NOINS_REASON noins_reason.;
	format NUM_FAM num_people.;
	format NUM_HH num_people.;
	format OOP_DEN_GRP puf_oop.;
	format OOP_OTH_GRP puf_oop.;
	format OOP_RX_GRP puf_oop.;
	format pol_party party.;
	format PROB_PAYING puf_yn.;
	format rsn_provider provider.;
	format RXDRUGS_12M puf_yn.;
	format SPEAK_ADD puf_yn.;
	format SPK_SPANISH spanish.;
	format SPK_OTHER spk_other.;
	format SPEC_12M puf_yn.;
	format STUDENT puf_yn.;
	format TIME_LASTCVRD tm_without.;
	format URBAN puf_urban.;
	format USOC puf_yn.;
	format USOC_TYPE puf_usoc.;
	format VETERAN puf_yn.;
	format VISIT_12M puf_yn.;
	format WHITE white.;

quit;

